import { TerminalStage } from '../../stages';
/**
 * Return a terminal stage that groups pipeline elements by the keys returned by `keyExtractor` argument.
 * Elements that return the same key will be grouped together in an array used as the value in the mapping.
 *
 * Optionally, each grouped element can be transformed by providing a second argument.
 *
 * @param keyExtractor The function that instructs this collector how the key is extracted from each element.
 * @param valueMapper The optional argument used to transform each grouped element.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 * @template VAL The optional type parameter of each grouped element to transform to.
 *
 * @returns
 */
export declare function groupBy<IN, KEY, VAL>(keyExtractor: (element: IN) => KEY, valueMapper: (element: IN) => VAL): TerminalStage<IN, Map<KEY, VAL[]>>;
export declare function groupBy<IN, KEY>(keyExtractor: (element: IN) => KEY): TerminalStage<IN, Map<KEY, IN[]>>;
